#include "latitude.h"

int main(int argc, char *argv[]) {
    QCoreApplication::setOrganizationName("linfati");
    QCoreApplication::setOrganizationDomain("linfati.com");
    QCoreApplication::setApplicationName("GoogleLatitude");

    QApplication app(argc, argv);

    LatitudeGUI gui;
    gui.show();

    return app.exec();
}
